==> lxqt-session_0.17.1.orig.tar.xz: lxqt-session-0.17.1/lxqt-leave/translations/lxqt-leave_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Wat wilt u dat de computer doet?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="55"/>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="73"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="60"/>
        <source>Shutdown</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="65"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="70"/>
        <source>Lock screen</source>
        <translation>Beeldscherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="78"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Logout.</source>
        <translation>Afmelden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Lockscreen.</source>
        <translation>Scherm vergrendelen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Suspend.</source>
        <translation>Pauzestand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Hibernate.</source>
        <translation>Slaapstand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Shutdown.</source>
        <translation>Afsluiten.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Reboot.</source>
        <translation>Herstarten.</translation>
    </message>
</context>
</TS>

==> lxqt-session_2.2.0.orig.tar.xz: lxqt-session-2.2.0/lxqt-leave/translations/lxqt-leave_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Wat wilt u met de computer doen?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="79"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Shutdown</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="71"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="76"/>
        <source>Lock screen</source>
        <translation>Beeldscherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="84"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Logout.</source>
        <translation>Afmelden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Lockscreen.</source>
        <translation>Scherm vergrendelen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Suspend.</source>
        <translation>Pauzestand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Hibernate.</source>
        <translation>Slaapstand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Shutdown.</source>
        <translation>Afsluiten.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reboot.</source>
        <translation>Herstarten.</translation>
    </message>
</context>
</TS>
